# Changelog

<!--next-version-placeholder-->

## v0.1.0 (2022-02-17)
### Feature
* `wt` shorter name to calls script ([`ece11c8`](https://github.com/iamtalhaasghar/whats-trending/commit/ece11c8ef62ffc203f8bca98100e141dd0300ba9))
* Setup semantic python versioning ([`2505b80`](https://github.com/iamtalhaasghar/whats-trending/commit/2505b80f10215740bf60dad888b9533837ec9757))

### Fix
* Graceful exit if request hit rate limit reached ([`8b23b67`](https://github.com/iamtalhaasghar/whats-trending/commit/8b23b67b6f6b804b9abe8a2709a6be39636e5811))
